.. AUTO-GENERATED FILE -- DO NOT EDIT!

models.sklearn_wrap
===================

Module: :mod:`models.sklearn_wrap`
----------------------------------
Inheritance diagram for ``ISLP.models.sklearn_wrap``:

.. inheritance-diagram:: ISLP.models.sklearn_wrap 
   :parts: 3

.. automodule:: ISLP.models.sklearn_wrap

.. currentmodule:: ISLP.models.sklearn_wrap

Classes
-------

:class:`sklearn_selected`
~~~~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: sklearn_selected
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`sklearn_selection_path`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: sklearn_selection_path
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`sklearn_sm`
~~~~~~~~~~~~~~~~~~~


.. autoclass:: sklearn_sm
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
